import argparse
import sys
from azure.keyvault.secrets import SecretClient
from azure.identity import DefaultAzureCredential
from azure.core.exceptions import AzureError

parser = argparse.ArgumentParser(description="access-key-vault.py")
parser.add_argument('--keyvault', '-v',
                    help="Name of Azure Key Vault",
                    required=True)
parser.add_argument('--secretname', '-s',
                    help='Name of secret to query',
                    required=True)
args = parser.parse_args()
keyVaultName = args.keyvault
secretName = args.secretname

KVUri = f"https://{keyVaultName}.vault.azure.net"

try:
    credential = DefaultAzureCredential()
    client = SecretClient(vault_url=KVUri, credential=credential)
    retrieved_secret = client.get_secret(secretName)

    print(f"{retrieved_secret.value}")
except AzureError as e:
    print(f"AzureError: <{e.__class__.__name__}> <{e}>", file=sys.stderr)
    sys.exit(1)
except Exception as e:
    print(f"Error: <{e.__class__.__name__}> <{e}>", file=sys.stderr)
    sys.exit(1)

